-- name: [CS] Pianta
-- description: Delfino Isle's chaotic neutral creature        \n\n\\#ff7777\\This Pack requires Character Select\nto use as a Library!

--[[
    API Documentation for Character Select can be found below:
    https://github.com/Squishy6094/character-select-coop/wiki/API-Documentation

    Use this if you're curious on how anything here works >v<
]]

local TEXT_MOD_NAME = "Pianta"

-- Stops mod from loading if Character Select isn't on
if not _G.charSelectExists then
    djui_popup_create("\\#ffffdc\\\n"..TEXT_MOD_NAME.."\nRequires the Character Select Mod\nto use as a Library!\n\nPlease turn on the Character Select Mod\nand Restart the Room!", 6)
    return 0
end

local E_MODEL_CUSTOM_MODEL = smlua_model_util_get_id("pianta_geo") -- Located in "actors"
local TEX_CUSTOM_LIFE_ICON = get_texture_info("pianta_icon") -- Located in "textures"


-- All Located in "sound"
local VOICETABLE_PIANTA = {
    --[CHAR_SOUND_OKEY_DOKEY] = 'GetStar2.ogg', -- Starting game
	[CHAR_SOUND_LETS_A_GO] = 'GetStar2.ogg', -- Starting level
	[CHAR_SOUND_PUNCH_YAH] = 'Punch1.ogg', -- Punch 1
	[CHAR_SOUND_PUNCH_WAH] = 'Punch2.ogg', -- Punch 2
	[CHAR_SOUND_PUNCH_HOO] = 'Punch3.ogg', -- Punch 3
	[CHAR_SOUND_YAH_WAH_HOO] = {'Jump1.ogg', 'Jump2.ogg', 'Jump3.ogg'}, -- First/Second jump sounds
	[CHAR_SOUND_HOOHOO] = {'DoubleJump1.ogg', 'DoubleJump2.ogg'}, -- Third jump sound
	[CHAR_SOUND_YAHOO_WAHA_YIPPEE] = {'TripleJump1.ogg', 'LongJump3.ogg'}, -- Triple jump sounds
	[CHAR_SOUND_UH] = 'Damage2.ogg', -- Wall bonk
	[CHAR_SOUND_UH2] = 'Silent.ogg', -- Landing after long jump
	[CHAR_SOUND_UH2_2] = 'Silent.ogg', -- Same sound as UH2; jumping onto ledge
	[CHAR_SOUND_HAHA] = 'Silent.ogg', -- Landing triple jump
	[CHAR_SOUND_YAHOO] = {'LongJump1.ogg', 'LongJump2.ogg', 'LongJump3.ogg'}, -- Long jump
	[CHAR_SOUND_DOH] = 'Damage1.ogg', -- Long jump wall bonk
	[CHAR_SOUND_WHOA] = 'GrabLedge.ogg', -- Grabbing ledge
	[CHAR_SOUND_EEUH] = 'DoubleJump2.ogg', -- Climbing over ledge
	[CHAR_SOUND_WAAAOOOW] = 'Falling.ogg', -- Falling a long distance
	[CHAR_SOUND_TWIRL_BOUNCE] = 'LongJump1.ogg', -- Bouncing off of a flower spring
	[CHAR_SOUND_GROUND_POUND_WAH] = 'Silent.ogg', 
	[CHAR_SOUND_HRMM] = 'GrabItem.ogg', -- Lifting something
	[CHAR_SOUND_HERE_WE_GO] = {'GetStar.ogg', 'GetStar2.ogg', 'GetStar3.ogg'}, -- Star get
	[CHAR_SOUND_SO_LONGA_BOWSER] = 'ThrowBowser.ogg', -- Throwing Bowser
--DAMAGE
	[CHAR_SOUND_ATTACKED] = {'Damage1.ogg', 'Damage2.ogg'}, -- Damaged
	[CHAR_SOUND_PANTING] = 'Silent.ogg', -- Low health
	[CHAR_SOUND_ON_FIRE] = 'Falling.ogg', -- Burned
--SLEEP SOUNDS
	[CHAR_SOUND_IMA_TIRED] = 'Silent.ogg', -- Mario feeling tired
	[CHAR_SOUND_YAWNING] = 'Yawn.ogg', -- Mario yawning before he sits down to sleep
	[CHAR_SOUND_SNORING1] = 'Silent.ogg', -- Snore Inhale
	[CHAR_SOUND_SNORING2] = 'Snore.ogg', -- Exhale
	[CHAR_SOUND_SNORING3] = 'Silent.ogg', -- Sleep talking / mumbling
--COUGHING (USED IN THE GAS MAZE)
	[CHAR_SOUND_COUGHING1] = 'Silent.ogg', -- Cough take 1
	[CHAR_SOUND_COUGHING2] = 'Silent.ogg', -- Cough take 2
	[CHAR_SOUND_COUGHING3] = 'Silent.ogg', -- Cough take 3
--DEATH
	[CHAR_SOUND_DYING] = 'Dying.ogg', -- Dying from damage
	[CHAR_SOUND_DROWNING] = 'Drowning.ogg', -- Running out of air underwater
	[CHAR_SOUND_MAMA_MIA] = 'Falling.ogg' -- Booted out of level
}

-- All Located in "actors"
local CAPTABLE_PIANTA = {
    normal = smlua_model_util_get_id("piantavc_geo"),
    wing = smlua_model_util_get_id("piantawc_geo"),
    metal = smlua_model_util_get_id("piantamc_geo"),
}

local PALETTE_PIANTA = {
    [PANTS]  = "0DFF00",
    [SHIRT]  = "0DFF00",
    [GLOVES] = "ffffff",
    [SHOES]  = "ffffff",
    [HAIR]   = "0DFF00",
    [SKIN]   = "00C1FF",
    [CAP]    = "00C1FF",
}

local CSloaded = false
local function on_character_select_load()
    CT_PIANTA = _G.charSelect.character_add("Pianta", {"Delfino Isle's chaotic neutral creature", ""}, "Garrulous64", {r = 0, g = 120, b = 255}, E_MODEL_CUSTOM_MODEL, CT_PIANTA, TEX_CUSTOM_LIFE_ICON)
    _G.charSelect.character_add_caps(E_MODEL_CUSTOM_MODEL, CAPTABLE_PIANTA)
    _G.charSelect.character_add_voice(E_MODEL_CUSTOM_MODEL, VOICETABLE_PIANTA)
    _G.charSelect.character_add_palette_preset(E_MODEL_CUSTOM_MODEL, PALETTE_PIANTA)

    CSloaded = true
end

local function on_character_sound(m, sound)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_PIANTA then return _G.charSelect.voice.sound(m, sound) end
end

local function on_character_snore(m)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_PIANTA then return _G.charSelect.voice.snore(m) end
end

hook_event(HOOK_ON_MODS_LOADED, on_character_select_load)
hook_event(HOOK_CHARACTER_SOUND, on_character_sound)
hook_event(HOOK_MARIO_UPDATE, on_character_snore)